@@ -36,12 +36,25 @@ decl_blend_fn(BF(dav1d_blend_vl256, rvv));
 decl_blend_dir_fn(BF(dav1d_blend_h_vl256, rvv));
 decl_blend_dir_fn(BF(dav1d_blend_v_vl256, rvv));
 
+decl_blend_fn(BF(dav1d_blend_vl512, rvv));
+decl_blend_dir_fn(BF(dav1d_blend_h_vl512, rvv));
+decl_blend_dir_fn(BF(dav1d_blend_v_vl512, rvv));
+
 decl_avg_fn(BF(dav1d_avg, rvv));
 decl_w_avg_fn(BF(dav1d_w_avg, rvv));
 decl_mask_fn(BF(dav1d_mask, rvv));
 
+decl_w_mask_fn(BF(dav1d_w_mask_444, rvv));
+decl_w_mask_fn(BF(dav1d_w_mask_422, rvv));
+decl_w_mask_fn(BF(dav1d_w_mask_420, rvv));
+
+decl_w_mask_fn(BF(dav1d_w_mask_444_vl256, rvv));
+decl_w_mask_fn(BF(dav1d_w_mask_422_vl256, rvv));
+decl_w_mask_fn(BF(dav1d_w_mask_420_vl256, rvv));
+
 decl_warp8x8_fn(BF(dav1d_warp_8x8, rvv));
 decl_warp8x8t_fn(BF(dav1d_warp_8x8t, rvv));
+decl_emu_edge_fn(BF(dav1d_emu_edge, rvv));
 
 static ALWAYS_INLINE void mc_dsp_init_riscv(Dav1dMCDSPContext *const c) {
   const unsigned flags = dav1d_get_cpu_flags();
@@ -56,12 +69,18 @@ static ALWAYS_INLINE void mc_dsp_init_riscv(Dav1dMCDSPContext *const c) {
     c->blend_v = BF(dav1d_blend_v_vl256, rvv);
   }
 
+  if (dav1d_get_vlen() >= 512) {
+    c->blend = BF(dav1d_blend_vl512, rvv);
+    c->blend_v = BF(dav1d_blend_v_vl512, rvv);
+  }
+
 #if BITDEPTH == 8
   c->blend_h = BF(dav1d_blend_h, rvv);
+  c->emu_edge = BF(dav1d_emu_edge, rvv);
 
-  if (dav1d_get_vlen() >= 256) {
-    c->blend_h = BF(dav1d_blend_h_vl256, rvv);
-  }
+  c->w_mask[0] = BF(dav1d_w_mask_444, rvv);
+  c->w_mask[1] = BF(dav1d_w_mask_422, rvv);
+  c->w_mask[2] = BF(dav1d_w_mask_420, rvv);
 
   c->avg     = BF(dav1d_avg, rvv);
   c->w_avg   = BF(dav1d_w_avg, rvv);
@@ -69,5 +88,16 @@ static ALWAYS_INLINE void mc_dsp_init_riscv(Dav1dMCDSPContext *const c) {
 
   c->warp8x8 = BF(dav1d_warp_8x8, rvv);
   c->warp8x8t = BF(dav1d_warp_8x8t, rvv);
+
+  if (dav1d_get_vlen() >= 256) {
+    c->blend_h = BF(dav1d_blend_h_vl256, rvv);
+
+    c->w_mask[0] = BF(dav1d_w_mask_444_vl256, rvv);
+    c->w_mask[1] = BF(dav1d_w_mask_422_vl256, rvv);
+    c->w_mask[2] = BF(dav1d_w_mask_420_vl256, rvv);
+  }
+  if (dav1d_get_vlen() >= 512) {
+    c->blend_h = BF(dav1d_blend_h_vl512, rvv);
+  }
 #endif
 }
